"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateDescribeAlarms = void 0;
const CloudWatchClient_1 = require("../CloudWatchClient");
const DescribeAlarmsCommand_1 = require("../commands/DescribeAlarmsCommand");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new DescribeAlarmsCommand_1.DescribeAlarmsCommand(input), ...args);
};
async function* paginateDescribeAlarms(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxRecords"] = config.pageSize;
        if (config.client instanceof CloudWatchClient_1.CloudWatchClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected CloudWatch | CloudWatchClient");
        }
        yield page;
        const prevToken = token;
        token = page.NextToken;
        hasNext = !!(token && (!config.stopOnSameToken || token !== prevToken));
    }
    return undefined;
}
exports.paginateDescribeAlarms = paginateDescribeAlarms;
