import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CloudWatchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudWatchClient";
import { PutManagedInsightRulesInput, PutManagedInsightRulesOutput } from "../models/models_0";
/**
 * The input for {@link PutManagedInsightRulesCommand}.
 */
export interface PutManagedInsightRulesCommandInput extends PutManagedInsightRulesInput {
}
/**
 * The output of {@link PutManagedInsightRulesCommand}.
 */
export interface PutManagedInsightRulesCommandOutput extends PutManagedInsightRulesOutput, __MetadataBearer {
}
/**
 * <p>
 * 			Creates a managed Contributor Insights rule
 * 			for a specified Amazon Web Services resource.
 * 			When you enable a managed rule,
 * 			you create a Contributor Insights rule
 * 			that collects data
 * 			from Amazon Web Services services.
 * 			You cannot edit these rules
 * 			with <code>PutInsightRule</code>.
 * 			The rules can be enabled, disabled, and deleted using <code>EnableInsightRules</code>, <code>DisableInsightRules</code>, and <code>DeleteInsightRules</code>.
 * 			If a previously created managed rule is currently disabled,
 * 			a subsequent call
 * 			to this API will re-enable it.
 * 			Use <code>ListManagedInsightRules</code>
 * 			to describe all available rules.
 *
 * 		</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudWatchClient, PutManagedInsightRulesCommand } from "@aws-sdk/client-cloudwatch"; // ES Modules import
 * // const { CloudWatchClient, PutManagedInsightRulesCommand } = require("@aws-sdk/client-cloudwatch"); // CommonJS import
 * const client = new CloudWatchClient(config);
 * const command = new PutManagedInsightRulesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link PutManagedInsightRulesCommandInput} for command's `input` shape.
 * @see {@link PutManagedInsightRulesCommandOutput} for command's `response` shape.
 * @see {@link CloudWatchClientResolvedConfig | config} for CloudWatchClient's `config` shape.
 *
 */
export declare class PutManagedInsightRulesCommand extends $Command<PutManagedInsightRulesCommandInput, PutManagedInsightRulesCommandOutput, CloudWatchClientResolvedConfig> {
    readonly input: PutManagedInsightRulesCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: PutManagedInsightRulesCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CloudWatchClientResolvedConfig, options?: __HttpHandlerOptions): Handler<PutManagedInsightRulesCommandInput, PutManagedInsightRulesCommandOutput>;
    private serialize;
    private deserialize;
}
