import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { CloudWatchClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudWatchClient";
import { StartMetricStreamsInput, StartMetricStreamsOutput } from "../models/models_0";
/**
 * The input for {@link StartMetricStreamsCommand}.
 */
export interface StartMetricStreamsCommandInput extends StartMetricStreamsInput {
}
/**
 * The output of {@link StartMetricStreamsCommand}.
 */
export interface StartMetricStreamsCommandOutput extends StartMetricStreamsOutput, __MetadataBearer {
}
/**
 * <p>Starts the streaming of metrics for one or more of your metric streams.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudWatchClient, StartMetricStreamsCommand } from "@aws-sdk/client-cloudwatch"; // ES Modules import
 * // const { CloudWatchClient, StartMetricStreamsCommand } = require("@aws-sdk/client-cloudwatch"); // CommonJS import
 * const client = new CloudWatchClient(config);
 * const command = new StartMetricStreamsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link StartMetricStreamsCommandInput} for command's `input` shape.
 * @see {@link StartMetricStreamsCommandOutput} for command's `response` shape.
 * @see {@link CloudWatchClientResolvedConfig | config} for CloudWatchClient's `config` shape.
 *
 */
export declare class StartMetricStreamsCommand extends $Command<StartMetricStreamsCommandInput, StartMetricStreamsCommandOutput, CloudWatchClientResolvedConfig> {
    readonly input: StartMetricStreamsCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: StartMetricStreamsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: CloudWatchClientResolvedConfig, options?: __HttpHandlerOptions): Handler<StartMetricStreamsCommandInput, StartMetricStreamsCommandOutput>;
    private serialize;
    private deserialize;
}
