import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { CloudWatchServiceException as __BaseException } from "./CloudWatchServiceException";
export declare enum ActionsSuppressedBy {
  Alarm = "Alarm",
  ExtensionPeriod = "ExtensionPeriod",
  WaitPeriod = "WaitPeriod",
}
export declare enum AlarmType {
  CompositeAlarm = "CompositeAlarm",
  MetricAlarm = "MetricAlarm",
}
export declare enum HistoryItemType {
  Action = "Action",
  ConfigurationUpdate = "ConfigurationUpdate",
  StateUpdate = "StateUpdate",
}
export interface AlarmHistoryItem {
  AlarmName?: string;
  AlarmType?: AlarmType | string;
  Timestamp?: Date;
  HistoryItemType?: HistoryItemType | string;
  HistorySummary?: string;
  HistoryData?: string;
}
export interface Range {
  StartTime: Date | undefined;
  EndTime: Date | undefined;
}
export interface AnomalyDetectorConfiguration {
  ExcludedTimeRanges?: Range[];
  MetricTimezone?: string;
}
export interface Dimension {
  Name: string | undefined;
  Value: string | undefined;
}
export interface Metric {
  Namespace?: string;
  MetricName?: string;
  Dimensions?: Dimension[];
}
export declare enum StandardUnit {
  Bits = "Bits",
  Bits_Second = "Bits/Second",
  Bytes = "Bytes",
  Bytes_Second = "Bytes/Second",
  Count = "Count",
  Count_Second = "Count/Second",
  Gigabits = "Gigabits",
  Gigabits_Second = "Gigabits/Second",
  Gigabytes = "Gigabytes",
  Gigabytes_Second = "Gigabytes/Second",
  Kilobits = "Kilobits",
  Kilobits_Second = "Kilobits/Second",
  Kilobytes = "Kilobytes",
  Kilobytes_Second = "Kilobytes/Second",
  Megabits = "Megabits",
  Megabits_Second = "Megabits/Second",
  Megabytes = "Megabytes",
  Megabytes_Second = "Megabytes/Second",
  Microseconds = "Microseconds",
  Milliseconds = "Milliseconds",
  None = "None",
  Percent = "Percent",
  Seconds = "Seconds",
  Terabits = "Terabits",
  Terabits_Second = "Terabits/Second",
  Terabytes = "Terabytes",
  Terabytes_Second = "Terabytes/Second",
}
export interface MetricStat {
  Metric: Metric | undefined;
  Period: number | undefined;
  Stat: string | undefined;
  Unit?: StandardUnit | string;
}
export interface MetricDataQuery {
  Id: string | undefined;
  MetricStat?: MetricStat;
  Expression?: string;
  Label?: string;
  ReturnData?: boolean;
  Period?: number;
  AccountId?: string;
}
export interface MetricMathAnomalyDetector {
  MetricDataQueries?: MetricDataQuery[];
}
export interface SingleMetricAnomalyDetector {
  Namespace?: string;
  MetricName?: string;
  Dimensions?: Dimension[];
  Stat?: string;
}
export declare enum AnomalyDetectorStateValue {
  PENDING_TRAINING = "PENDING_TRAINING",
  TRAINED = "TRAINED",
  TRAINED_INSUFFICIENT_DATA = "TRAINED_INSUFFICIENT_DATA",
}
export interface AnomalyDetector {
  Namespace?: string;
  MetricName?: string;
  Dimensions?: Dimension[];
  Stat?: string;
  Configuration?: AnomalyDetectorConfiguration;
  StateValue?: AnomalyDetectorStateValue | string;
  SingleMetricAnomalyDetector?: SingleMetricAnomalyDetector;
  MetricMathAnomalyDetector?: MetricMathAnomalyDetector;
}
export declare enum AnomalyDetectorType {
  METRIC_MATH = "METRIC_MATH",
  SINGLE_METRIC = "SINGLE_METRIC",
}
export interface PartialFailure {
  FailureResource?: string;
  ExceptionType?: string;
  FailureCode?: string;
  FailureDescription?: string;
}
export declare enum ComparisonOperator {
  GreaterThanOrEqualToThreshold = "GreaterThanOrEqualToThreshold",
  GreaterThanThreshold = "GreaterThanThreshold",
  GreaterThanUpperThreshold = "GreaterThanUpperThreshold",
  LessThanLowerOrGreaterThanUpperThreshold = "LessThanLowerOrGreaterThanUpperThreshold",
  LessThanLowerThreshold = "LessThanLowerThreshold",
  LessThanOrEqualToThreshold = "LessThanOrEqualToThreshold",
  LessThanThreshold = "LessThanThreshold",
}
export declare enum StateValue {
  ALARM = "ALARM",
  INSUFFICIENT_DATA = "INSUFFICIENT_DATA",
  OK = "OK",
}
export interface CompositeAlarm {
  ActionsEnabled?: boolean;
  AlarmActions?: string[];
  AlarmArn?: string;
  AlarmConfigurationUpdatedTimestamp?: Date;
  AlarmDescription?: string;
  AlarmName?: string;
  AlarmRule?: string;
  InsufficientDataActions?: string[];
  OKActions?: string[];
  StateReason?: string;
  StateReasonData?: string;
  StateUpdatedTimestamp?: Date;
  StateValue?: StateValue | string;
  StateTransitionedTimestamp?: Date;
  ActionsSuppressedBy?: ActionsSuppressedBy | string;
  ActionsSuppressedReason?: string;
  ActionsSuppressor?: string;
  ActionsSuppressorWaitPeriod?: number;
  ActionsSuppressorExtensionPeriod?: number;
}
export declare class ConcurrentModificationException extends __BaseException {
  readonly name: "ConcurrentModificationException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<
      ConcurrentModificationException,
      __BaseException
    >
  );
}
export interface DashboardEntry {
  DashboardName?: string;
  DashboardArn?: string;
  LastModified?: Date;
  Size?: number;
}
export interface DashboardValidationMessage {
  DataPath?: string;
  Message?: string;
}
export declare class DashboardInvalidInputError extends __BaseException {
  readonly name: "DashboardInvalidInputError";
  readonly $fault: "client";
  dashboardValidationMessages?: DashboardValidationMessage[];
  constructor(
    opts: __ExceptionOptionType<DashboardInvalidInputError, __BaseException>
  );
}
export declare class DashboardNotFoundError extends __BaseException {
  readonly name: "DashboardNotFoundError";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<DashboardNotFoundError, __BaseException>
  );
}
export interface Datapoint {
  Timestamp?: Date;
  SampleCount?: number;
  Average?: number;
  Sum?: number;
  Minimum?: number;
  Maximum?: number;
  Unit?: StandardUnit | string;
  ExtendedStatistics?: Record<string, number>;
}
export interface DeleteAlarmsInput {
  AlarmNames: string[] | undefined;
}
export declare class ResourceNotFound extends __BaseException {
  readonly name: "ResourceNotFound";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<ResourceNotFound, __BaseException>);
}
export interface DeleteAnomalyDetectorInput {
  Namespace?: string;
  MetricName?: string;
  Dimensions?: Dimension[];
  Stat?: string;
  SingleMetricAnomalyDetector?: SingleMetricAnomalyDetector;
  MetricMathAnomalyDetector?: MetricMathAnomalyDetector;
}
export interface DeleteAnomalyDetectorOutput {}
export declare class InternalServiceFault extends __BaseException {
  readonly name: "InternalServiceFault";
  readonly $fault: "server";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<InternalServiceFault, __BaseException>
  );
}
export declare class InvalidParameterCombinationException extends __BaseException {
  readonly name: "InvalidParameterCombinationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      InvalidParameterCombinationException,
      __BaseException
    >
  );
}
export declare class InvalidParameterValueException extends __BaseException {
  readonly name: "InvalidParameterValueException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidParameterValueException, __BaseException>
  );
}
export declare class MissingRequiredParameterException extends __BaseException {
  readonly name: "MissingRequiredParameterException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      MissingRequiredParameterException,
      __BaseException
    >
  );
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  ResourceType?: string;
  ResourceId?: string;
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export interface DeleteDashboardsInput {
  DashboardNames: string[] | undefined;
}
export interface DeleteDashboardsOutput {}
export interface DeleteInsightRulesInput {
  RuleNames: string[] | undefined;
}
export interface DeleteInsightRulesOutput {
  Failures?: PartialFailure[];
}
export interface DeleteMetricStreamInput {
  Name: string | undefined;
}
export interface DeleteMetricStreamOutput {}
export declare enum ScanBy {
  TIMESTAMP_ASCENDING = "TimestampAscending",
  TIMESTAMP_DESCENDING = "TimestampDescending",
}
export interface DescribeAlarmHistoryInput {
  AlarmName?: string;
  AlarmTypes?: (AlarmType | string)[];
  HistoryItemType?: HistoryItemType | string;
  StartDate?: Date;
  EndDate?: Date;
  MaxRecords?: number;
  NextToken?: string;
  ScanBy?: ScanBy | string;
}
export interface DescribeAlarmHistoryOutput {
  AlarmHistoryItems?: AlarmHistoryItem[];
  NextToken?: string;
}
export declare class InvalidNextToken extends __BaseException {
  readonly name: "InvalidNextToken";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidNextToken, __BaseException>);
}
export interface DescribeAlarmsInput {
  AlarmNames?: string[];
  AlarmNamePrefix?: string;
  AlarmTypes?: (AlarmType | string)[];
  ChildrenOfAlarmName?: string;
  ParentsOfAlarmName?: string;
  StateValue?: StateValue | string;
  ActionPrefix?: string;
  MaxRecords?: number;
  NextToken?: string;
}
export declare enum EvaluationState {
  PARTIAL_DATA = "PARTIAL_DATA",
}
export declare enum Statistic {
  Average = "Average",
  Maximum = "Maximum",
  Minimum = "Minimum",
  SampleCount = "SampleCount",
  Sum = "Sum",
}
export interface MetricAlarm {
  AlarmName?: string;
  AlarmArn?: string;
  AlarmDescription?: string;
  AlarmConfigurationUpdatedTimestamp?: Date;
  ActionsEnabled?: boolean;
  OKActions?: string[];
  AlarmActions?: string[];
  InsufficientDataActions?: string[];
  StateValue?: StateValue | string;
  StateReason?: string;
  StateReasonData?: string;
  StateUpdatedTimestamp?: Date;
  MetricName?: string;
  Namespace?: string;
  Statistic?: Statistic | string;
  ExtendedStatistic?: string;
  Dimensions?: Dimension[];
  Period?: number;
  Unit?: StandardUnit | string;
  EvaluationPeriods?: number;
  DatapointsToAlarm?: number;
  Threshold?: number;
  ComparisonOperator?: ComparisonOperator | string;
  TreatMissingData?: string;
  EvaluateLowSampleCountPercentile?: string;
  Metrics?: MetricDataQuery[];
  ThresholdMetricId?: string;
  EvaluationState?: EvaluationState | string;
  StateTransitionedTimestamp?: Date;
}
export interface DescribeAlarmsOutput {
  CompositeAlarms?: CompositeAlarm[];
  MetricAlarms?: MetricAlarm[];
  NextToken?: string;
}
export interface DescribeAlarmsForMetricInput {
  MetricName: string | undefined;
  Namespace: string | undefined;
  Statistic?: Statistic | string;
  ExtendedStatistic?: string;
  Dimensions?: Dimension[];
  Period?: number;
  Unit?: StandardUnit | string;
}
export interface DescribeAlarmsForMetricOutput {
  MetricAlarms?: MetricAlarm[];
}
export interface DescribeAnomalyDetectorsInput {
  NextToken?: string;
  MaxResults?: number;
  Namespace?: string;
  MetricName?: string;
  Dimensions?: Dimension[];
  AnomalyDetectorTypes?: (AnomalyDetectorType | string)[];
}
export interface DescribeAnomalyDetectorsOutput {
  AnomalyDetectors?: AnomalyDetector[];
  NextToken?: string;
}
export interface DescribeInsightRulesInput {
  NextToken?: string;
  MaxResults?: number;
}
export interface InsightRule {
  Name: string | undefined;
  State: string | undefined;
  Schema: string | undefined;
  Definition: string | undefined;
  ManagedRule?: boolean;
}
export interface DescribeInsightRulesOutput {
  NextToken?: string;
  InsightRules?: InsightRule[];
}
export interface DimensionFilter {
  Name: string | undefined;
  Value?: string;
}
export interface DisableAlarmActionsInput {
  AlarmNames: string[] | undefined;
}
export interface DisableInsightRulesInput {
  RuleNames: string[] | undefined;
}
export interface DisableInsightRulesOutput {
  Failures?: PartialFailure[];
}
export interface EnableAlarmActionsInput {
  AlarmNames: string[] | undefined;
}
export interface EnableInsightRulesInput {
  RuleNames: string[] | undefined;
}
export interface EnableInsightRulesOutput {
  Failures?: PartialFailure[];
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export interface GetDashboardInput {
  DashboardName: string | undefined;
}
export interface GetDashboardOutput {
  DashboardArn?: string;
  DashboardBody?: string;
  DashboardName?: string;
}
export interface GetInsightRuleReportInput {
  RuleName: string | undefined;
  StartTime: Date | undefined;
  EndTime: Date | undefined;
  Period: number | undefined;
  MaxContributorCount?: number;
  Metrics?: string[];
  OrderBy?: string;
}
export interface InsightRuleContributorDatapoint {
  Timestamp: Date | undefined;
  ApproximateValue: number | undefined;
}
export interface InsightRuleContributor {
  Keys: string[] | undefined;
  ApproximateAggregateValue: number | undefined;
  Datapoints: InsightRuleContributorDatapoint[] | undefined;
}
export interface InsightRuleMetricDatapoint {
  Timestamp: Date | undefined;
  UniqueContributors?: number;
  MaxContributorValue?: number;
  SampleCount?: number;
  Average?: number;
  Sum?: number;
  Minimum?: number;
  Maximum?: number;
}
export interface GetInsightRuleReportOutput {
  KeyLabels?: string[];
  AggregationStatistic?: string;
  AggregateValue?: number;
  ApproximateUniqueCount?: number;
  Contributors?: InsightRuleContributor[];
  MetricDatapoints?: InsightRuleMetricDatapoint[];
}
export interface LabelOptions {
  Timezone?: string;
}
export interface GetMetricDataInput {
  MetricDataQueries: MetricDataQuery[] | undefined;
  StartTime: Date | undefined;
  EndTime: Date | undefined;
  NextToken?: string;
  ScanBy?: ScanBy | string;
  MaxDatapoints?: number;
  LabelOptions?: LabelOptions;
}
export interface MessageData {
  Code?: string;
  Value?: string;
}
export declare enum StatusCode {
  COMPLETE = "Complete",
  FORBIDDEN = "Forbidden",
  INTERNAL_ERROR = "InternalError",
  PARTIAL_DATA = "PartialData",
}
export interface MetricDataResult {
  Id?: string;
  Label?: string;
  Timestamps?: Date[];
  Values?: number[];
  StatusCode?: StatusCode | string;
  Messages?: MessageData[];
}
export interface GetMetricDataOutput {
  MetricDataResults?: MetricDataResult[];
  NextToken?: string;
  Messages?: MessageData[];
}
export interface GetMetricStatisticsInput {
  Namespace: string | undefined;
  MetricName: string | undefined;
  Dimensions?: Dimension[];
  StartTime: Date | undefined;
  EndTime: Date | undefined;
  Period: number | undefined;
  Statistics?: (Statistic | string)[];
  ExtendedStatistics?: string[];
  Unit?: StandardUnit | string;
}
export interface GetMetricStatisticsOutput {
  Label?: string;
  Datapoints?: Datapoint[];
}
export interface GetMetricStreamInput {
  Name: string | undefined;
}
export interface MetricStreamFilter {
  Namespace?: string;
}
export declare enum MetricStreamOutputFormat {
  JSON = "json",
  OPEN_TELEMETRY_0_7 = "opentelemetry0.7",
}
export interface MetricStreamStatisticsMetric {
  Namespace: string | undefined;
  MetricName: string | undefined;
}
export interface MetricStreamStatisticsConfiguration {
  IncludeMetrics: MetricStreamStatisticsMetric[] | undefined;
  AdditionalStatistics: string[] | undefined;
}
export interface GetMetricStreamOutput {
  Arn?: string;
  Name?: string;
  IncludeFilters?: MetricStreamFilter[];
  ExcludeFilters?: MetricStreamFilter[];
  FirehoseArn?: string;
  RoleArn?: string;
  State?: string;
  CreationDate?: Date;
  LastUpdateDate?: Date;
  OutputFormat?: MetricStreamOutputFormat | string;
  StatisticsConfigurations?: MetricStreamStatisticsConfiguration[];
  IncludeLinkedAccountsMetrics?: boolean;
}
export interface GetMetricWidgetImageInput {
  MetricWidget: string | undefined;
  OutputFormat?: string;
}
export interface GetMetricWidgetImageOutput {
  MetricWidgetImage?: Uint8Array;
}
export interface ListDashboardsInput {
  DashboardNamePrefix?: string;
  NextToken?: string;
}
export interface ListDashboardsOutput {
  DashboardEntries?: DashboardEntry[];
  NextToken?: string;
}
export interface ListManagedInsightRulesInput {
  ResourceARN: string | undefined;
  NextToken?: string;
  MaxResults?: number;
}
export interface ManagedRuleState {
  RuleName: string | undefined;
  State: string | undefined;
}
export interface ManagedRuleDescription {
  TemplateName?: string;
  ResourceARN?: string;
  RuleState?: ManagedRuleState;
}
export interface ListManagedInsightRulesOutput {
  ManagedRules?: ManagedRuleDescription[];
  NextToken?: string;
}
export declare enum RecentlyActive {
  PT3H = "PT3H",
}
export interface ListMetricsInput {
  Namespace?: string;
  MetricName?: string;
  Dimensions?: DimensionFilter[];
  NextToken?: string;
  RecentlyActive?: RecentlyActive | string;
  IncludeLinkedAccounts?: boolean;
  OwningAccount?: string;
}
export interface ListMetricsOutput {
  Metrics?: Metric[];
  NextToken?: string;
  OwningAccounts?: string[];
}
export interface ListMetricStreamsInput {
  NextToken?: string;
  MaxResults?: number;
}
export interface MetricStreamEntry {
  Arn?: string;
  CreationDate?: Date;
  LastUpdateDate?: Date;
  Name?: string;
  FirehoseArn?: string;
  State?: string;
  OutputFormat?: MetricStreamOutputFormat | string;
}
export interface ListMetricStreamsOutput {
  NextToken?: string;
  Entries?: MetricStreamEntry[];
}
export interface ListTagsForResourceInput {
  ResourceARN: string | undefined;
}
export interface Tag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface ListTagsForResourceOutput {
  Tags?: Tag[];
}
export interface PutAnomalyDetectorInput {
  Namespace?: string;
  MetricName?: string;
  Dimensions?: Dimension[];
  Stat?: string;
  Configuration?: AnomalyDetectorConfiguration;
  SingleMetricAnomalyDetector?: SingleMetricAnomalyDetector;
  MetricMathAnomalyDetector?: MetricMathAnomalyDetector;
}
export interface PutAnomalyDetectorOutput {}
export declare class LimitExceededFault extends __BaseException {
  readonly name: "LimitExceededFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<LimitExceededFault, __BaseException>);
}
export interface PutCompositeAlarmInput {
  ActionsEnabled?: boolean;
  AlarmActions?: string[];
  AlarmDescription?: string;
  AlarmName: string | undefined;
  AlarmRule: string | undefined;
  InsufficientDataActions?: string[];
  OKActions?: string[];
  Tags?: Tag[];
  ActionsSuppressor?: string;
  ActionsSuppressorWaitPeriod?: number;
  ActionsSuppressorExtensionPeriod?: number;
}
export interface PutDashboardInput {
  DashboardName: string | undefined;
  DashboardBody: string | undefined;
}
export interface PutDashboardOutput {
  DashboardValidationMessages?: DashboardValidationMessage[];
}
export interface PutInsightRuleInput {
  RuleName: string | undefined;
  RuleState?: string;
  RuleDefinition: string | undefined;
  Tags?: Tag[];
}
export interface PutInsightRuleOutput {}
export interface ManagedRule {
  TemplateName: string | undefined;
  ResourceARN: string | undefined;
  Tags?: Tag[];
}
export interface PutManagedInsightRulesInput {
  ManagedRules: ManagedRule[] | undefined;
}
export interface PutManagedInsightRulesOutput {
  Failures?: PartialFailure[];
}
export interface PutMetricAlarmInput {
  AlarmName: string | undefined;
  AlarmDescription?: string;
  ActionsEnabled?: boolean;
  OKActions?: string[];
  AlarmActions?: string[];
  InsufficientDataActions?: string[];
  MetricName?: string;
  Namespace?: string;
  Statistic?: Statistic | string;
  ExtendedStatistic?: string;
  Dimensions?: Dimension[];
  Period?: number;
  Unit?: StandardUnit | string;
  EvaluationPeriods: number | undefined;
  DatapointsToAlarm?: number;
  Threshold?: number;
  ComparisonOperator: ComparisonOperator | string | undefined;
  TreatMissingData?: string;
  EvaluateLowSampleCountPercentile?: string;
  Metrics?: MetricDataQuery[];
  Tags?: Tag[];
  ThresholdMetricId?: string;
}
export interface StatisticSet {
  SampleCount: number | undefined;
  Sum: number | undefined;
  Minimum: number | undefined;
  Maximum: number | undefined;
}
export interface MetricDatum {
  MetricName: string | undefined;
  Dimensions?: Dimension[];
  Timestamp?: Date;
  Value?: number;
  StatisticValues?: StatisticSet;
  Values?: number[];
  Counts?: number[];
  Unit?: StandardUnit | string;
  StorageResolution?: number;
}
export interface PutMetricDataInput {
  Namespace: string | undefined;
  MetricData: MetricDatum[] | undefined;
}
export interface PutMetricStreamInput {
  Name: string | undefined;
  IncludeFilters?: MetricStreamFilter[];
  ExcludeFilters?: MetricStreamFilter[];
  FirehoseArn: string | undefined;
  RoleArn: string | undefined;
  OutputFormat: MetricStreamOutputFormat | string | undefined;
  Tags?: Tag[];
  StatisticsConfigurations?: MetricStreamStatisticsConfiguration[];
  IncludeLinkedAccountsMetrics?: boolean;
}
export interface PutMetricStreamOutput {
  Arn?: string;
}
export declare class InvalidFormatFault extends __BaseException {
  readonly name: "InvalidFormatFault";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<InvalidFormatFault, __BaseException>);
}
export interface SetAlarmStateInput {
  AlarmName: string | undefined;
  StateValue: StateValue | string | undefined;
  StateReason: string | undefined;
  StateReasonData?: string;
}
export interface StartMetricStreamsInput {
  Names: string[] | undefined;
}
export interface StartMetricStreamsOutput {}
export interface StopMetricStreamsInput {
  Names: string[] | undefined;
}
export interface StopMetricStreamsOutput {}
export interface TagResourceInput {
  ResourceARN: string | undefined;
  Tags: Tag[] | undefined;
}
export interface TagResourceOutput {}
export interface UntagResourceInput {
  ResourceARN: string | undefined;
  TagKeys: string[] | undefined;
}
export interface UntagResourceOutput {}
export declare const AlarmHistoryItemFilterSensitiveLog: (
  obj: AlarmHistoryItem
) => any;
export declare const RangeFilterSensitiveLog: (obj: Range) => any;
export declare const AnomalyDetectorConfigurationFilterSensitiveLog: (
  obj: AnomalyDetectorConfiguration
) => any;
export declare const DimensionFilterSensitiveLog: (obj: Dimension) => any;
export declare const MetricFilterSensitiveLog: (obj: Metric) => any;
export declare const MetricStatFilterSensitiveLog: (obj: MetricStat) => any;
export declare const MetricDataQueryFilterSensitiveLog: (
  obj: MetricDataQuery
) => any;
export declare const MetricMathAnomalyDetectorFilterSensitiveLog: (
  obj: MetricMathAnomalyDetector
) => any;
export declare const SingleMetricAnomalyDetectorFilterSensitiveLog: (
  obj: SingleMetricAnomalyDetector
) => any;
export declare const AnomalyDetectorFilterSensitiveLog: (
  obj: AnomalyDetector
) => any;
export declare const PartialFailureFilterSensitiveLog: (
  obj: PartialFailure
) => any;
export declare const CompositeAlarmFilterSensitiveLog: (
  obj: CompositeAlarm
) => any;
export declare const DashboardEntryFilterSensitiveLog: (
  obj: DashboardEntry
) => any;
export declare const DashboardValidationMessageFilterSensitiveLog: (
  obj: DashboardValidationMessage
) => any;
export declare const DatapointFilterSensitiveLog: (obj: Datapoint) => any;
export declare const DeleteAlarmsInputFilterSensitiveLog: (
  obj: DeleteAlarmsInput
) => any;
export declare const DeleteAnomalyDetectorInputFilterSensitiveLog: (
  obj: DeleteAnomalyDetectorInput
) => any;
export declare const DeleteAnomalyDetectorOutputFilterSensitiveLog: (
  obj: DeleteAnomalyDetectorOutput
) => any;
export declare const DeleteDashboardsInputFilterSensitiveLog: (
  obj: DeleteDashboardsInput
) => any;
export declare const DeleteDashboardsOutputFilterSensitiveLog: (
  obj: DeleteDashboardsOutput
) => any;
export declare const DeleteInsightRulesInputFilterSensitiveLog: (
  obj: DeleteInsightRulesInput
) => any;
export declare const DeleteInsightRulesOutputFilterSensitiveLog: (
  obj: DeleteInsightRulesOutput
) => any;
export declare const DeleteMetricStreamInputFilterSensitiveLog: (
  obj: DeleteMetricStreamInput
) => any;
export declare const DeleteMetricStreamOutputFilterSensitiveLog: (
  obj: DeleteMetricStreamOutput
) => any;
export declare const DescribeAlarmHistoryInputFilterSensitiveLog: (
  obj: DescribeAlarmHistoryInput
) => any;
export declare const DescribeAlarmHistoryOutputFilterSensitiveLog: (
  obj: DescribeAlarmHistoryOutput
) => any;
export declare const DescribeAlarmsInputFilterSensitiveLog: (
  obj: DescribeAlarmsInput
) => any;
export declare const MetricAlarmFilterSensitiveLog: (obj: MetricAlarm) => any;
export declare const DescribeAlarmsOutputFilterSensitiveLog: (
  obj: DescribeAlarmsOutput
) => any;
export declare const DescribeAlarmsForMetricInputFilterSensitiveLog: (
  obj: DescribeAlarmsForMetricInput
) => any;
export declare const DescribeAlarmsForMetricOutputFilterSensitiveLog: (
  obj: DescribeAlarmsForMetricOutput
) => any;
export declare const DescribeAnomalyDetectorsInputFilterSensitiveLog: (
  obj: DescribeAnomalyDetectorsInput
) => any;
export declare const DescribeAnomalyDetectorsOutputFilterSensitiveLog: (
  obj: DescribeAnomalyDetectorsOutput
) => any;
export declare const DescribeInsightRulesInputFilterSensitiveLog: (
  obj: DescribeInsightRulesInput
) => any;
export declare const InsightRuleFilterSensitiveLog: (obj: InsightRule) => any;
export declare const DescribeInsightRulesOutputFilterSensitiveLog: (
  obj: DescribeInsightRulesOutput
) => any;
export declare const DimensionFilterFilterSensitiveLog: (
  obj: DimensionFilter
) => any;
export declare const DisableAlarmActionsInputFilterSensitiveLog: (
  obj: DisableAlarmActionsInput
) => any;
export declare const DisableInsightRulesInputFilterSensitiveLog: (
  obj: DisableInsightRulesInput
) => any;
export declare const DisableInsightRulesOutputFilterSensitiveLog: (
  obj: DisableInsightRulesOutput
) => any;
export declare const EnableAlarmActionsInputFilterSensitiveLog: (
  obj: EnableAlarmActionsInput
) => any;
export declare const EnableInsightRulesInputFilterSensitiveLog: (
  obj: EnableInsightRulesInput
) => any;
export declare const EnableInsightRulesOutputFilterSensitiveLog: (
  obj: EnableInsightRulesOutput
) => any;
export declare const GetDashboardInputFilterSensitiveLog: (
  obj: GetDashboardInput
) => any;
export declare const GetDashboardOutputFilterSensitiveLog: (
  obj: GetDashboardOutput
) => any;
export declare const GetInsightRuleReportInputFilterSensitiveLog: (
  obj: GetInsightRuleReportInput
) => any;
export declare const InsightRuleContributorDatapointFilterSensitiveLog: (
  obj: InsightRuleContributorDatapoint
) => any;
export declare const InsightRuleContributorFilterSensitiveLog: (
  obj: InsightRuleContributor
) => any;
export declare const InsightRuleMetricDatapointFilterSensitiveLog: (
  obj: InsightRuleMetricDatapoint
) => any;
export declare const GetInsightRuleReportOutputFilterSensitiveLog: (
  obj: GetInsightRuleReportOutput
) => any;
export declare const LabelOptionsFilterSensitiveLog: (obj: LabelOptions) => any;
export declare const GetMetricDataInputFilterSensitiveLog: (
  obj: GetMetricDataInput
) => any;
export declare const MessageDataFilterSensitiveLog: (obj: MessageData) => any;
export declare const MetricDataResultFilterSensitiveLog: (
  obj: MetricDataResult
) => any;
export declare const GetMetricDataOutputFilterSensitiveLog: (
  obj: GetMetricDataOutput
) => any;
export declare const GetMetricStatisticsInputFilterSensitiveLog: (
  obj: GetMetricStatisticsInput
) => any;
export declare const GetMetricStatisticsOutputFilterSensitiveLog: (
  obj: GetMetricStatisticsOutput
) => any;
export declare const GetMetricStreamInputFilterSensitiveLog: (
  obj: GetMetricStreamInput
) => any;
export declare const MetricStreamFilterFilterSensitiveLog: (
  obj: MetricStreamFilter
) => any;
export declare const MetricStreamStatisticsMetricFilterSensitiveLog: (
  obj: MetricStreamStatisticsMetric
) => any;
export declare const MetricStreamStatisticsConfigurationFilterSensitiveLog: (
  obj: MetricStreamStatisticsConfiguration
) => any;
export declare const GetMetricStreamOutputFilterSensitiveLog: (
  obj: GetMetricStreamOutput
) => any;
export declare const GetMetricWidgetImageInputFilterSensitiveLog: (
  obj: GetMetricWidgetImageInput
) => any;
export declare const GetMetricWidgetImageOutputFilterSensitiveLog: (
  obj: GetMetricWidgetImageOutput
) => any;
export declare const ListDashboardsInputFilterSensitiveLog: (
  obj: ListDashboardsInput
) => any;
export declare const ListDashboardsOutputFilterSensitiveLog: (
  obj: ListDashboardsOutput
) => any;
export declare const ListManagedInsightRulesInputFilterSensitiveLog: (
  obj: ListManagedInsightRulesInput
) => any;
export declare const ManagedRuleStateFilterSensitiveLog: (
  obj: ManagedRuleState
) => any;
export declare const ManagedRuleDescriptionFilterSensitiveLog: (
  obj: ManagedRuleDescription
) => any;
export declare const ListManagedInsightRulesOutputFilterSensitiveLog: (
  obj: ListManagedInsightRulesOutput
) => any;
export declare const ListMetricsInputFilterSensitiveLog: (
  obj: ListMetricsInput
) => any;
export declare const ListMetricsOutputFilterSensitiveLog: (
  obj: ListMetricsOutput
) => any;
export declare const ListMetricStreamsInputFilterSensitiveLog: (
  obj: ListMetricStreamsInput
) => any;
export declare const MetricStreamEntryFilterSensitiveLog: (
  obj: MetricStreamEntry
) => any;
export declare const ListMetricStreamsOutputFilterSensitiveLog: (
  obj: ListMetricStreamsOutput
) => any;
export declare const ListTagsForResourceInputFilterSensitiveLog: (
  obj: ListTagsForResourceInput
) => any;
export declare const TagFilterSensitiveLog: (obj: Tag) => any;
export declare const ListTagsForResourceOutputFilterSensitiveLog: (
  obj: ListTagsForResourceOutput
) => any;
export declare const PutAnomalyDetectorInputFilterSensitiveLog: (
  obj: PutAnomalyDetectorInput
) => any;
export declare const PutAnomalyDetectorOutputFilterSensitiveLog: (
  obj: PutAnomalyDetectorOutput
) => any;
export declare const PutCompositeAlarmInputFilterSensitiveLog: (
  obj: PutCompositeAlarmInput
) => any;
export declare const PutDashboardInputFilterSensitiveLog: (
  obj: PutDashboardInput
) => any;
export declare const PutDashboardOutputFilterSensitiveLog: (
  obj: PutDashboardOutput
) => any;
export declare const PutInsightRuleInputFilterSensitiveLog: (
  obj: PutInsightRuleInput
) => any;
export declare const PutInsightRuleOutputFilterSensitiveLog: (
  obj: PutInsightRuleOutput
) => any;
export declare const ManagedRuleFilterSensitiveLog: (obj: ManagedRule) => any;
export declare const PutManagedInsightRulesInputFilterSensitiveLog: (
  obj: PutManagedInsightRulesInput
) => any;
export declare const PutManagedInsightRulesOutputFilterSensitiveLog: (
  obj: PutManagedInsightRulesOutput
) => any;
export declare const PutMetricAlarmInputFilterSensitiveLog: (
  obj: PutMetricAlarmInput
) => any;
export declare const StatisticSetFilterSensitiveLog: (obj: StatisticSet) => any;
export declare const MetricDatumFilterSensitiveLog: (obj: MetricDatum) => any;
export declare const PutMetricDataInputFilterSensitiveLog: (
  obj: PutMetricDataInput
) => any;
export declare const PutMetricStreamInputFilterSensitiveLog: (
  obj: PutMetricStreamInput
) => any;
export declare const PutMetricStreamOutputFilterSensitiveLog: (
  obj: PutMetricStreamOutput
) => any;
export declare const SetAlarmStateInputFilterSensitiveLog: (
  obj: SetAlarmStateInput
) => any;
export declare const StartMetricStreamsInputFilterSensitiveLog: (
  obj: StartMetricStreamsInput
) => any;
export declare const StartMetricStreamsOutputFilterSensitiveLog: (
  obj: StartMetricStreamsOutput
) => any;
export declare const StopMetricStreamsInputFilterSensitiveLog: (
  obj: StopMetricStreamsInput
) => any;
export declare const StopMetricStreamsOutputFilterSensitiveLog: (
  obj: StopMetricStreamsOutput
) => any;
export declare const TagResourceInputFilterSensitiveLog: (
  obj: TagResourceInput
) => any;
export declare const TagResourceOutputFilterSensitiveLog: (
  obj: TagResourceOutput
) => any;
export declare const UntagResourceInputFilterSensitiveLog: (
  obj: UntagResourceInput
) => any;
export declare const UntagResourceOutputFilterSensitiveLog: (
  obj: UntagResourceOutput
) => any;
